@@ -8,19 +8,21 @@ class DataRequest:
         encoding = reqDetails.get('encoding')
         address = reqDetails.get('address')
         timeout = reqDetails.get('timeout')
+        networkTimeout = reqDetails.get('networkTimeout')
         options = {
             u'tasks': reqDetails.get('tasks'),
             u'taskId': reqDetails.get('taskId'),
-            u'path': reqDetails.get('dataPath')
+            u'dataPath': reqDetails.get('dataPath')
         }
         self.encoding = Encoding(encoding)
         content = self.encoding.encode(options, plain_encode=True)
         self.request = dict()
         self.request.update(address)
-        self.request.update({"content": content, "timeout": timeout})
+        self.request.update({"content": content, "timeout": timeout, "networkTimeout": networkTimeout})
 
     def invoke(self):
         try:
+            print('tcp://' + self.request['host'] + ':' + str(self.request['port']))
             adapter = ZMQRequest(self.request)
             response = adapter.invokeAdapter()
             return self.encoding.decode(response)
